================
ChessTab - About
================


ChessTab lists the games on a database and displays the scores of selected games.


Run 'python -m pip show chesstab' at a command line to display version and dependency (requires and required-by) information.

Version numbers for the packages listed under 'requires' are given in the setup.py file.

Run 'python -m pip check' at a command line to display discrepancies between required and installed versions of packages.

'python' may need to be replaced by <path to>python<version> depending on the system configuration: 'python3.8' for example.

ChessTab uses features introduced at Python3.4 but declared stable at Python3.6.

Dependencies:

 Python3.6, or later versions when available, must be installed to run ChessTab.

 tkinter, part of Python, must be installed to run ChessTab.  Sometimes this is installed separately.

 One of sqlite3, apsw, bsddb3, or berkeleydb, must be installed to run ChessTab.  sqlite3 is part of Python, but sometimes is installed separately.  apsw, bsddb3, and berkeleydb, are packages for Python, so must be installed separately.

